@@ -63,11 +63,6 @@ have_func('rb_during_gc', 'ruby.h')
 have_func('rb_gc_add_event_hook', ['ruby.h', 'node.h'])
 have_func('rb_postponed_job_register_one', 'ruby.h')
 
-# increase message size on linux
-if RUBY_PLATFORM =~ /linux/
-  $defs.push("-DBUF_SIZE=256")
-end
-
 # warnings save lives
 $CFLAGS << " -Wall "
 
